@@ -29,7 +29,8 @@ import os
 from lxml import etree
 
 class Settings:
-    def save_config(self, mapsource, username, authtoken, profile):
+    def save_config(self, mapsource, username, authtoken, profile, twittuser,
+        twittpass):
         """Save the configuration parameters to the XML file
 
         @type   mapsource: string
@@ -48,11 +49,15 @@ class Settings:
         username_el = etree.SubElement(root, "username")
         authtoken_el = etree.SubElement(root, "authtoken")
         profile_el = etree.SubElement(root, "profile")
+        twittuser_el = etree.SubElement(root, "twittuser")
+        twittpass_el = etree.SubElement(root, "twittpass")
 
         mapsource_el.text = mapsource
         username_el.text = username
         authtoken_el.text = authtoken
         profile_el.text = profile
+        twittuser_el.text = twittuser
+        twittpass_el.text = twittpass
 
         xmltext = etree.tostring(root, pretty_print=True)
 
@@ -92,8 +97,22 @@ class Settings:
             profile =  root.getchildren()[3].text
             if not profile:
                 profile = ''
+            try:
+                twittuser =  root.getchildren()[4].text
+                if not twittuser:
+                    twittuser = ''
+            except IndexError:
+                twittuser = ''
 
-            data = [mapsource, username, authtoken, profile]
+            try:
+                twittpass =  root.getchildren()[5].text
+                if not twittpass:
+                    twittpass = ''
+            except IndexError:
+                twittpass = ''
+
+            data = [mapsource, username, authtoken, profile, twittuser,
+                    twittpass]
 
             return data
         else:
@@ -101,9 +120,13 @@ class Settings:
             username = ''
             authtoken = ''
             profile = ''
-            self.save_config(mapsource, username, authtoken, profile)
+            twittuser = ''
+            twittpass = ''
+            self.save_config(mapsource, username, authtoken, profile,
+                            twittuser, twittpass)
             print 'creating new default configuration'
-            data = [mapsource, username, authtoken, profile]
+            data = [mapsource, username, authtoken, profile, twittuser,
+                    twittpass]
             return data
 
     def open_configfile(self):
